@@ -31,20 +31,20 @@
 #define MAX_MEMORY_HEIGHT 4
 
 //#define TEXT_FONT gc_skin_font_board_huge_bold
-#define TEXT_FONT "Serif bold 28"
+#define TEXT_FONT "Sans bold 28"
 
 static gchar *op_fonts[10] =
   {
     "",
-    "Serif bold 28",
-    "Serif bold 24",
-    "Serif bold 20",
-    "Serif bold 20",
-    "Serif bold 17",
-    "Serif bold 13",
-    "Serif bold 13",
-    "Serif bold 13",
-    "Serif bold 11",
+    "Sans bold 28",
+    "Sans bold 24",
+    "Sans bold 20",
+    "Sans bold 20",
+    "Sans bold 17",
+    "Sans bold 13",
+    "Sans bold 13",
+    "Sans bold 13",
+    "Sans bold 11",
   };
 
 static GcomprisBoard *gcomprisBoard = NULL;
@@ -551,7 +551,7 @@ void get_random_token(int token_type, gint *returned_type, gchar **string, gchar
 	int i, j;
 	i = k %  add_levelDescription[gcomprisBoard->level][0];
 	j = k /  add_levelDescription[gcomprisBoard->level][0];
-	result = g_strdup_printf("%d%s%d",i,op_add,j);
+	result = g_strdup_printf("%d %s %d",i,op_add,j);
 	second = g_strdup_printf("%d",i+j);;
 	break;
       }
@@ -560,7 +560,7 @@ void get_random_token(int token_type, gint *returned_type, gchar **string, gchar
 	int i, j;
 	i = k %  minus_levelDescription[gcomprisBoard->level][0];
 	j = k /  minus_levelDescription[gcomprisBoard->level][0];
-	result = g_strdup_printf("%d%s%d",i+j,op_minus,i);
+	result = g_strdup_printf("%d %s %d",i+j,op_minus,i);
 	second = g_strdup_printf("%d",j);;
 	break;
       }
@@ -569,7 +569,7 @@ void get_random_token(int token_type, gint *returned_type, gchar **string, gchar
 	int i, j;
 	i = k %  mult_levelDescription[gcomprisBoard->level][0];
 	j = k /  mult_levelDescription[gcomprisBoard->level][0];
-	result = g_strdup_printf("%d%s%d",i,op_mult,j);
+	result = g_strdup_printf("%d %s %d",i,op_mult,j);
 	second = g_strdup_printf("%d",i*j);;
 	break;
       }
@@ -579,7 +579,7 @@ void get_random_token(int token_type, gint *returned_type, gchar **string, gchar
 	i1 = k %  div_levelDescription[gcomprisBoard->level][0];
 	if (i1==0) skip=TRUE;
 	i2 = k /  div_levelDescription[gcomprisBoard->level][0];
-	result = g_strdup_printf("%d%s%d",i1*i2,op_div,i1);
+	result = g_strdup_printf("%d %s %d",i1*i2,op_div,i1);
 	second = g_strdup_printf("%d",i2);
 	break;
       }
@@ -1357,7 +1357,7 @@ static void create_item(GnomeCanvasGroup *parent)
 				       "x", (double) (width2)/2,
 				       "y", (double) (height2)/2,
 				       "anchor", GTK_ANCHOR_CENTER,
-				       "fill_color_rgba", 0x225AFFFF,
+				       "fill_color_rgba", 0xFFFFFFFF,
 				       NULL);
 
 	    }
