@@ -74,6 +74,7 @@ static gchar *linguas[] = {
   "es_ES.UTF-8", 	N_("Spanish"),
   "eu_ES.UTF-8",	N_("Basque"),
   "dz_BT.UTF-8",	N_("Dzongkha"),
+  "fa_IR.UTF-8", 	N_("Persian"),
   "fi_FI.UTF-8", 	N_("Finnish"),
   "fr_FR.UTF-8", 	N_("French"),
   "ga_IE.UTF-8", 	N_("Irish (Gaelic)"),
@@ -115,6 +116,7 @@ static gchar *linguas[] = {
   "th_TH.UTF-8",	N_("Thai"),
   "tr_TR.UTF-8",	N_("Turkish"),
   "ur_PK.UTF-8",	N_("Urdu"),
+  "uk_UA.UTF8",		N_("Ukrainian"),
   "vi_VN.UTF-8",	N_("Vietnamese"),
   "wa_BE.UTF-8",	N_("Walloon"),
   "zh_CN.UTF-8",	N_("Chinese (Simplified)"),
