@@ -51,7 +51,6 @@
 #define DEFAULT_DATABASE "gcompris_sqlite.db"
 
 /* Multiple instance check */
-static gchar *lock_file;
 #define GC_LOCK_FILE "gcompris.lock"
 #define GC_LOCK_LIMIT 30 /* seconds */
 
@@ -68,6 +67,7 @@ static gint board_widget_key_press_callback (GtkWidget   *widget,
 					    GdkEventKey *event,
 					    gpointer     client_data);
 void gc_terminate(int signum);
+static void single_instance_release();
 
 /*
  * For the Activation dialog
@@ -77,11 +77,11 @@ int gc_activation_check(char *code);
 static void activation_enter_callback(GtkWidget *widget,
 				      GtkWidget *entry );
 static void activation_done();
-static void display_activation_dialog();
+static int display_activation_dialog();
 static GnomeCanvasItem *activation_item;
 static GtkEntry *widget_activation_entry;
 #else
-#define display_activation_dialog()
+#define display_activation_dialog() FALSE
 #endif
 
 
@@ -608,6 +608,53 @@ void gc_cursor_set(guint gdk_cursor_type)
   }
 }
 
+static GcomprisBoard *get_board_to_start()
+{
+  GcomprisBoard *board_to_start;
+
+  /* By default, the menu will be started */
+  board_to_start = properties->menu_board;
+
+  /* Get and Run the root menu */
+  if(properties->administration)
+    {
+      board_to_start = gc_menu_section_get("/administration/administration");
+    }
+  else
+    {
+      /* If we have a profile defined, run the login screen
+       * (the login screen is a board that uppon login completion
+       * starts the menu)
+       */
+      if(properties->profile && properties->profile->group_ids)
+	{
+	  gboolean found = FALSE;
+
+	  GList *group_id;
+
+	  for (group_id = properties->profile->group_ids; group_id != NULL; group_id = group_id->next)
+	    if (g_list_length(gc_db_users_from_group_get( *((int *) group_id->data))) > 0){
+	      found = TRUE;
+	      break;
+	    }
+
+	  /* No profile start normally */
+	  if (found)
+	    board_to_start = gc_menu_section_get("/login/login");
+	  else {
+	    board_to_start = gc_menu_section_get(properties->root_menu);
+	    /* this will set user information to system one */
+	    gc_profile_set_current_user(NULL);
+	  }
+	}
+      else
+	/* this will set user information to system one */
+	gc_profile_set_current_user(NULL);
+    }
+
+  return board_to_start;
+}
+
 static void setup_window ()
 {
   GcomprisBoard *board_to_start;
@@ -733,51 +780,13 @@ static void setup_window ()
   /* Save the root_menu */
   properties->menu_board = gc_menu_section_get(properties->root_menu);
 
-  /* By default, the menu will be started */
-  board_to_start = properties->menu_board;
-
-  /* Get and Run the root menu */
-  if(properties->administration)
-    {
-      board_to_start = gc_menu_section_get("/administration/administration");
-    }
-  else
-    {
-      /* If we have a profile defined, run the login screen
-       * (the login screen is a board that uppon login completion
-       * starts the menu)
-       */
-      if(properties->profile && properties->profile->group_ids)
-	{
-	  gboolean found = FALSE;
-
-	  GList *group_id;
-
-	  for (group_id = properties->profile->group_ids; group_id != NULL; group_id = group_id->next)
-	    if (g_list_length(gc_db_users_from_group_get( *((int *) group_id->data))) > 0){
-	      found = TRUE;
-	      break;
-	    }
-
-	  /* No profile start normally */
-	  if (found)
-	    board_to_start = gc_menu_section_get("/login/login");
-	  else {
-	    board_to_start = gc_menu_section_get(properties->root_menu);
-	    /* this will set user information to system one */
-	    gc_profile_set_current_user(NULL);
-	  }
-	}
-      else
-	/* this will set user information to system one */
-	gc_profile_set_current_user(NULL);
-    }
-
-    /* Run the bar */
+  /* Run the bar */
   gc_bar_start(canvas_bar);
 
   init_background();
 
+  board_to_start = get_board_to_start();
+
   if(!board_to_start) {
     gchar *tmpstr= g_strdup_printf("Couldn't find the board menu %s, or plugin execution error", properties->root_menu);
     gc_dialog(tmpstr, NULL);
@@ -788,38 +797,43 @@ static void setup_window ()
     g_free(tmpstr);
   } else {
     g_warning("Fine, we got the gcomprisBoardMenu, xml boards parsing went fine");
-    gc_board_play(board_to_start);
+    if(!display_activation_dialog())
+      gc_board_play(board_to_start);
   }
 
-  display_activation_dialog();
 
 }
 
 #ifdef STATIC_MODULE
-extern int gc_board_number_in_demo;
 /** Display the activation dialog for the windows version
  *
+ * return TRUE is the dialog is display, FALSE instead.
  */
-void
+int
 display_activation_dialog()
 {
   int board_count = 0;
+  int gc_board_number_in_demo = 0;
   GList *list;
   guint  key_is_valid = 0;
 
   key_is_valid = gc_activation_check(properties->key);
 
   if(key_is_valid == 1)
-    return;
+    return FALSE;
 
   /* Count non menu boards */
   for (list = gc_menu_get_boards(); list != NULL; list = list->next)
     {
       GcomprisBoard *board = list->data;
       if (strcmp(board->type, "menu") != 0 &&
-	  strcmp(board->section, "/experimental") != 0 &&
-	  strcmp(board->section, "/administration") != 0)
-	board_count++;
+	  strncmp(board->section, "/experimental", 13) != 0)
+	{
+	  board_count++;
+	  gc_board_check_file(board);
+	  if(board->plugin)
+	      gc_board_number_in_demo++;
+	}
     }
 
   /* Entry area */
@@ -843,12 +857,12 @@ display_activation_dialog()
   gtk_widget_show(GTK_WIDGET(widget_activation_entry));
   gtk_entry_set_text(GTK_ENTRY(widget_activation_entry), "CODE");
 
-  gc_board_stop();
-
   char *msg = g_strdup_printf(_("GCompris is free software released under the GPL License. In order to support its development, the Windows version provides only %d of the %d activities. You can get the full version for a small fee at\n<http://gcompris.net>\nThe GNU/Linux version does not have this restriction. Note that GCompris is being developed to free schools from monopolistic software vendors. If you also believe that we should teach freedom to children, please consider using GNU/Linux. Get more information at FSF:\n<http://www.fsf.org/philosophy>"),
 			      gc_board_number_in_demo, board_count);
   gc_dialog(msg, activation_done);
   g_free(msg);
+
+  return TRUE;
 }
 
 /**
@@ -941,7 +955,7 @@ activation_done()
       activation_enter_callback(GTK_WIDGET(widget_activation_entry), NULL);
     }
 
-  gc_board_play(properties->menu_board);
+  gc_board_play( get_board_to_start());
   gtk_object_destroy (GTK_OBJECT(activation_item));
 }
 #endif
@@ -1050,6 +1064,7 @@ static void cleanup()
   signal(SIGINT,  NULL);
   signal(SIGSEGV, NULL);
 
+  single_instance_release(); /* Must be done before property destroy */
   gc_board_stop();
   gc_db_exit();
 #ifdef XF86_VIDMODE
@@ -1057,7 +1072,6 @@ static void cleanup()
 #endif
   gc_menu_destroy();
   gc_prop_destroy(gc_prop_get());
-  g_unlink(lock_file);
 }
 
 void gc_exit()
@@ -1109,6 +1123,14 @@ static void load_properties ()
   else
     g_warning("Binary relocation disabled");
 
+  /* usefull for OSX bundle app */
+#ifdef NSBUNDLE
+  exec_prefix = gcompris_nsbundle_resource ();
+#else
+  exec_prefix = gbr_find_exe_dir(NULL);
+#endif
+  g_warning("exec_prefix %s\n", (exec_prefix==NULL ? "NONE" : exec_prefix));
+
   prefix_dir = gbr_find_prefix(NULL);
 
   /* Check if we are in the source code (developper usage) */
@@ -1419,10 +1441,19 @@ start_bg_music (gchar *file)
 }
 
 /* Single instance Check */
+static void
+single_instance_release()
+{
+  gchar *lock_file = g_strdup_printf("%s/%s", properties->config_dir, GC_LOCK_FILE);
+
+  g_unlink(lock_file);
+  g_free(lock_file);
+}
+
 static void
 single_instance_check()
 {
-  lock_file = g_strdup_printf("%s/%s", properties->config_dir, GC_LOCK_FILE);
+  gchar *lock_file = g_strdup_printf("%s/%s", properties->config_dir, GC_LOCK_FILE);
   if(!popt_nolockcheck)
     {
       GTimeVal current_time;
@@ -1474,15 +1505,6 @@ main (int argc, char *argv[])
   GError *error = NULL;
   GOptionContext *context;
 
-  /* usefull for OSX bundle app */
-#ifdef NSBUNDLE
-  exec_prefix = gcompris_nsbundle_resource ();
-  printf("exec_prefix %s\n", exec_prefix);
-#else
-  exec_prefix = NULL;
-  printf("exec_prefix NULL\n");
-#endif
-
   /* First, Remove the gnome crash dialog because it locks the user when in full screen */
   signal(SIGSEGV, gc_terminate);
   signal(SIGINT, gc_terminate);
